@@ -1,4 +1,5 @@
 import uuid
+from abc import ABC, abstractmethod
 from datetime import datetime
 from enum import StrEnum
 
@@ -18,7 +19,7 @@ class RoomStatus(StrEnum):
     closed = 'closed'
 
 
-class BaseRoom(BaseModel):
+class BaseRoom(BaseModel, ABC):
     id: str = Field(alias='id_', default_factory=lambda: str(uuid.uuid4()))
     map: str = 'world'
     status: RoomStatus = RoomStatus.waiting
@@ -28,9 +29,10 @@ class BaseRoom(BaseModel):
 
     @validator("mode", always=True)
     def compute_mode(cls, value):
-        return cls.get_mode() or value
+        return cls.get_mode()
 
     @staticmethod
+    @abstractmethod
     def get_mode() -> RoomMode:
         pass
 
