@@ -5,7 +5,10 @@ from moontour_common.models.user import User
 
 
 class StreakRoom(BaseRoom):
-    mode = RoomMode.streak
+    @staticmethod
+    def get_mode() -> RoomMode:
+        return RoomMode.streak
+
     streak: int = 0
     phases: list[Phase] = []
     guesses: list[Guess] = []
